core_service

package
v5.7.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: Apache-2.0 Imports: 13 Imported by: 2

Documentation

Index

Constants

const (
	CoreService_GetHealthStatus_FullMethodName                = "/core_service.CoreService/GetHealthStatus"
	CoreService_RegisterAdapter_FullMethodName                = "/core_service.CoreService/RegisterAdapter"
	CoreService_DeviceUpdate_FullMethodName                   = "/core_service.CoreService/DeviceUpdate"
	CoreService_PortCreated_FullMethodName                    = "/core_service.CoreService/PortCreated"
	CoreService_PortsStateUpdate_FullMethodName               = "/core_service.CoreService/PortsStateUpdate"
	CoreService_DeleteAllPorts_FullMethodName                 = "/core_service.CoreService/DeleteAllPorts"
	CoreService_GetDevicePort_FullMethodName                  = "/core_service.CoreService/GetDevicePort"
	CoreService_ListDevicePorts_FullMethodName                = "/core_service.CoreService/ListDevicePorts"
	CoreService_DeviceStateUpdate_FullMethodName              = "/core_service.CoreService/DeviceStateUpdate"
	CoreService_DevicePMConfigUpdate_FullMethodName           = "/core_service.CoreService/DevicePMConfigUpdate"
	CoreService_ChildDeviceDetected_FullMethodName            = "/core_service.CoreService/ChildDeviceDetected"
	CoreService_ChildDevicesLost_FullMethodName               = "/core_service.CoreService/ChildDevicesLost"
	CoreService_ChildDevicesDetected_FullMethodName           = "/core_service.CoreService/ChildDevicesDetected"
	CoreService_GetDevice_FullMethodName                      = "/core_service.CoreService/GetDevice"
	CoreService_GetChildDevice_FullMethodName                 = "/core_service.CoreService/GetChildDevice"
	CoreService_GetChildDevices_FullMethodName                = "/core_service.CoreService/GetChildDevices"
	CoreService_SendPacketIn_FullMethodName                   = "/core_service.CoreService/SendPacketIn"
	CoreService_DeviceReasonUpdate_FullMethodName             = "/core_service.CoreService/DeviceReasonUpdate"
	CoreService_PortStateUpdate_FullMethodName                = "/core_service.CoreService/PortStateUpdate"
	CoreService_ReconcileChildDevices_FullMethodName          = "/core_service.CoreService/ReconcileChildDevices"
	CoreService_GetChildDeviceWithProxyAddress_FullMethodName = "/core_service.CoreService/GetChildDeviceWithProxyAddress"
	CoreService_GetPorts_FullMethodName                       = "/core_service.CoreService/GetPorts"
	CoreService_ChildrenStateUpdate_FullMethodName            = "/core_service.CoreService/ChildrenStateUpdate"
	CoreService_UpdateImageDownload_FullMethodName            = "/core_service.CoreService/UpdateImageDownload"
)

Variables

var CoreService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "core_service.CoreService",
	HandlerType: (*CoreServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterAdapter",
			Handler:    _CoreService_RegisterAdapter_Handler,
		},
		{
			MethodName: "DeviceUpdate",
			Handler:    _CoreService_DeviceUpdate_Handler,
		},
		{
			MethodName: "PortCreated",
			Handler:    _CoreService_PortCreated_Handler,
		},
		{
			MethodName: "PortsStateUpdate",
			Handler:    _CoreService_PortsStateUpdate_Handler,
		},
		{
			MethodName: "DeleteAllPorts",
			Handler:    _CoreService_DeleteAllPorts_Handler,
		},
		{
			MethodName: "GetDevicePort",
			Handler:    _CoreService_GetDevicePort_Handler,
		},
		{
			MethodName: "ListDevicePorts",
			Handler:    _CoreService_ListDevicePorts_Handler,
		},
		{
			MethodName: "DeviceStateUpdate",
			Handler:    _CoreService_DeviceStateUpdate_Handler,
		},
		{
			MethodName: "DevicePMConfigUpdate",
			Handler:    _CoreService_DevicePMConfigUpdate_Handler,
		},
		{
			MethodName: "ChildDeviceDetected",
			Handler:    _CoreService_ChildDeviceDetected_Handler,
		},
		{
			MethodName: "ChildDevicesLost",
			Handler:    _CoreService_ChildDevicesLost_Handler,
		},
		{
			MethodName: "ChildDevicesDetected",
			Handler:    _CoreService_ChildDevicesDetected_Handler,
		},
		{
			MethodName: "GetDevice",
			Handler:    _CoreService_GetDevice_Handler,
		},
		{
			MethodName: "GetChildDevice",
			Handler:    _CoreService_GetChildDevice_Handler,
		},
		{
			MethodName: "GetChildDevices",
			Handler:    _CoreService_GetChildDevices_Handler,
		},
		{
			MethodName: "SendPacketIn",
			Handler:    _CoreService_SendPacketIn_Handler,
		},
		{
			MethodName: "DeviceReasonUpdate",
			Handler:    _CoreService_DeviceReasonUpdate_Handler,
		},
		{
			MethodName: "PortStateUpdate",
			Handler:    _CoreService_PortStateUpdate_Handler,
		},
		{
			MethodName: "ReconcileChildDevices",
			Handler:    _CoreService_ReconcileChildDevices_Handler,
		},
		{
			MethodName: "GetChildDeviceWithProxyAddress",
			Handler:    _CoreService_GetChildDeviceWithProxyAddress_Handler,
		},
		{
			MethodName: "GetPorts",
			Handler:    _CoreService_GetPorts_Handler,
		},
		{
			MethodName: "ChildrenStateUpdate",
			Handler:    _CoreService_ChildrenStateUpdate_Handler,
		},
		{
			MethodName: "UpdateImageDownload",
			Handler:    _CoreService_UpdateImageDownload_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "GetHealthStatus",
			Handler:       _CoreService_GetHealthStatus_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "voltha_protos/core_services.proto",
}

CoreService_ServiceDesc is the grpc.ServiceDesc for CoreService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_voltha_protos_core_services_proto protoreflect.FileDescriptor

Functions

func RegisterCoreServiceServer

func RegisterCoreServiceServer(s grpc.ServiceRegistrar, srv CoreServiceServer)

Types

type CoreServiceClient

type CoreServiceClient interface {
	// GetHealthStatus is used by a CoreService client to verify connectivity
	// to the gRPC server hosting the CoreService service
	GetHealthStatus(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[common.Connection, health.HealthStatus], error)
	RegisterAdapter(ctx context.Context, in *core_adapter.AdapterRegistration, opts ...grpc.CallOption) (*emptypb.Empty, error)
	DeviceUpdate(ctx context.Context, in *voltha.Device, opts ...grpc.CallOption) (*emptypb.Empty, error)
	PortCreated(ctx context.Context, in *voltha.Port, opts ...grpc.CallOption) (*emptypb.Empty, error)
	PortsStateUpdate(ctx context.Context, in *core_adapter.PortStateFilter, opts ...grpc.CallOption) (*emptypb.Empty, error)
	DeleteAllPorts(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*emptypb.Empty, error)
	GetDevicePort(ctx context.Context, in *core_adapter.PortFilter, opts ...grpc.CallOption) (*voltha.Port, error)
	ListDevicePorts(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*voltha.Ports, error)
	DeviceStateUpdate(ctx context.Context, in *core_adapter.DeviceStateFilter, opts ...grpc.CallOption) (*emptypb.Empty, error)
	DevicePMConfigUpdate(ctx context.Context, in *voltha.PmConfigs, opts ...grpc.CallOption) (*emptypb.Empty, error)
	ChildDeviceDetected(ctx context.Context, in *core_adapter.DeviceDiscovery, opts ...grpc.CallOption) (*voltha.Device, error)
	ChildDevicesLost(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*emptypb.Empty, error)
	ChildDevicesDetected(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*emptypb.Empty, error)
	GetDevice(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*voltha.Device, error)
	GetChildDevice(ctx context.Context, in *core_adapter.ChildDeviceFilter, opts ...grpc.CallOption) (*voltha.Device, error)
	GetChildDevices(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*voltha.Devices, error)
	SendPacketIn(ctx context.Context, in *core_adapter.PacketIn, opts ...grpc.CallOption) (*emptypb.Empty, error)
	DeviceReasonUpdate(ctx context.Context, in *core_adapter.DeviceReason, opts ...grpc.CallOption) (*emptypb.Empty, error)
	PortStateUpdate(ctx context.Context, in *core_adapter.PortState, opts ...grpc.CallOption) (*emptypb.Empty, error)
	// Additional API found in the Core - unused?
	ReconcileChildDevices(ctx context.Context, in *common.ID, opts ...grpc.CallOption) (*emptypb.Empty, error)
	GetChildDeviceWithProxyAddress(ctx context.Context, in *voltha.Device_ProxyAddress, opts ...grpc.CallOption) (*voltha.Device, error)
	GetPorts(ctx context.Context, in *core_adapter.PortFilter, opts ...grpc.CallOption) (*voltha.Ports, error)
	ChildrenStateUpdate(ctx context.Context, in *core_adapter.DeviceStateFilter, opts ...grpc.CallOption) (*emptypb.Empty, error)
	UpdateImageDownload(ctx context.Context, in *voltha.ImageDownload, opts ...grpc.CallOption) (*emptypb.Empty, error)
}

CoreServiceClient is the client API for CoreService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

The CoreService is a gRPC service implemented by the Voltha RW-Core for the sole purpose of serving requests/updates from the Voltha adapters.

type CoreServiceServer

type CoreServiceServer interface {
	// GetHealthStatus is used by a CoreService client to verify connectivity
	// to the gRPC server hosting the CoreService service
	GetHealthStatus(grpc.BidiStreamingServer[common.Connection, health.HealthStatus]) error
	RegisterAdapter(context.Context, *core_adapter.AdapterRegistration) (*emptypb.Empty, error)
	DeviceUpdate(context.Context, *voltha.Device) (*emptypb.Empty, error)
	PortCreated(context.Context, *voltha.Port) (*emptypb.Empty, error)
	PortsStateUpdate(context.Context, *core_adapter.PortStateFilter) (*emptypb.Empty, error)
	DeleteAllPorts(context.Context, *common.ID) (*emptypb.Empty, error)
	GetDevicePort(context.Context, *core_adapter.PortFilter) (*voltha.Port, error)
	ListDevicePorts(context.Context, *common.ID) (*voltha.Ports, error)
	DeviceStateUpdate(context.Context, *core_adapter.DeviceStateFilter) (*emptypb.Empty, error)
	DevicePMConfigUpdate(context.Context, *voltha.PmConfigs) (*emptypb.Empty, error)
	ChildDeviceDetected(context.Context, *core_adapter.DeviceDiscovery) (*voltha.Device, error)
	ChildDevicesLost(context.Context, *common.ID) (*emptypb.Empty, error)
	ChildDevicesDetected(context.Context, *common.ID) (*emptypb.Empty, error)
	GetDevice(context.Context, *common.ID) (*voltha.Device, error)
	GetChildDevice(context.Context, *core_adapter.ChildDeviceFilter) (*voltha.Device, error)
	GetChildDevices(context.Context, *common.ID) (*voltha.Devices, error)
	SendPacketIn(context.Context, *core_adapter.PacketIn) (*emptypb.Empty, error)
	DeviceReasonUpdate(context.Context, *core_adapter.DeviceReason) (*emptypb.Empty, error)
	PortStateUpdate(context.Context, *core_adapter.PortState) (*emptypb.Empty, error)
	// Additional API found in the Core - unused?
	ReconcileChildDevices(context.Context, *common.ID) (*emptypb.Empty, error)
	GetChildDeviceWithProxyAddress(context.Context, *voltha.Device_ProxyAddress) (*voltha.Device, error)
	GetPorts(context.Context, *core_adapter.PortFilter) (*voltha.Ports, error)
	ChildrenStateUpdate(context.Context, *core_adapter.DeviceStateFilter) (*emptypb.Empty, error)
	UpdateImageDownload(context.Context, *voltha.ImageDownload) (*emptypb.Empty, error)
	// contains filtered or unexported methods
}

CoreServiceServer is the server API for CoreService service. All implementations must embed UnimplementedCoreServiceServer for forward compatibility.

The CoreService is a gRPC service implemented by the Voltha RW-Core for the sole purpose of serving requests/updates from the Voltha adapters.

type CoreService_GetHealthStatusClient

type CoreService_GetHealthStatusClient = grpc.BidiStreamingClient[common.Connection, health.HealthStatus]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type CoreService_GetHealthStatusServer

type CoreService_GetHealthStatusServer = grpc.BidiStreamingServer[common.Connection, health.HealthStatus]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedCoreServiceServer

type UnimplementedCoreServiceServer struct{}

UnimplementedCoreServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCoreServiceServer) ChildDeviceDetected

func (UnimplementedCoreServiceServer) ChildDevicesDetected

func (UnimplementedCoreServiceServer) ChildDevicesLost

func (UnimplementedCoreServiceServer) ChildrenStateUpdate

func (UnimplementedCoreServiceServer) DeleteAllPorts

func (UnimplementedCoreServiceServer) DevicePMConfigUpdate

func (UnimplementedCoreServiceServer) DeviceReasonUpdate

func (UnimplementedCoreServiceServer) DeviceStateUpdate

func (UnimplementedCoreServiceServer) DeviceUpdate

func (UnimplementedCoreServiceServer) GetChildDevice

func (UnimplementedCoreServiceServer) GetChildDeviceWithProxyAddress

func (UnimplementedCoreServiceServer) GetChildDevices

func (UnimplementedCoreServiceServer) GetDevice

func (UnimplementedCoreServiceServer) GetDevicePort

func (UnimplementedCoreServiceServer) GetHealthStatus

func (UnimplementedCoreServiceServer) GetPorts

func (UnimplementedCoreServiceServer) ListDevicePorts

func (UnimplementedCoreServiceServer) PortCreated

func (UnimplementedCoreServiceServer) PortStateUpdate

func (UnimplementedCoreServiceServer) PortsStateUpdate

func (UnimplementedCoreServiceServer) ReconcileChildDevices

func (UnimplementedCoreServiceServer) RegisterAdapter

func (UnimplementedCoreServiceServer) SendPacketIn

func (UnimplementedCoreServiceServer) UpdateImageDownload

type UnsafeCoreServiceServer added in v5.7.1

type UnsafeCoreServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeCoreServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CoreServiceServer will result in compilation errors.

Jump to