olt_inter_adapter_service

package
v5.7.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: Apache-2.0 Imports: 12 Imported by: 1

Documentation

Index

Constants

const (
	OltInterAdapterService_GetHealthStatus_FullMethodName        = "/olt_inter_adapter_service.OltInterAdapterService/GetHealthStatus"
	OltInterAdapterService_ProxyOmciRequest_FullMethodName       = "/olt_inter_adapter_service.OltInterAdapterService/ProxyOmciRequest"
	OltInterAdapterService_ProxyOmciRequests_FullMethodName      = "/olt_inter_adapter_service.OltInterAdapterService/ProxyOmciRequests"
	OltInterAdapterService_GetTechProfileInstance_FullMethodName = "/olt_inter_adapter_service.OltInterAdapterService/GetTechProfileInstance"
)

Variables

var File_voltha_protos_olt_inter_adapter_service_proto protoreflect.FileDescriptor
var OltInterAdapterService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "olt_inter_adapter_service.OltInterAdapterService",
	HandlerType: (*OltInterAdapterServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ProxyOmciRequest",
			Handler:    _OltInterAdapterService_ProxyOmciRequest_Handler,
		},
		{
			MethodName: "ProxyOmciRequests",
			Handler:    _OltInterAdapterService_ProxyOmciRequests_Handler,
		},
		{
			MethodName: "GetTechProfileInstance",
			Handler:    _OltInterAdapterService_GetTechProfileInstance_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "GetHealthStatus",
			Handler:       _OltInterAdapterService_GetHealthStatus_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "voltha_protos/olt_inter_adapter_service.proto",
}

OltInterAdapterService_ServiceDesc is the grpc.ServiceDesc for OltInterAdapterService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterOltInterAdapterServiceServer

func RegisterOltInterAdapterServiceServer(s grpc.ServiceRegistrar, srv OltInterAdapterServiceServer)

Types

type OltInterAdapterServiceClient

type OltInterAdapterServiceClient interface {
	// GetHealthStatus is used by a OltInterAdapterService client to detect a connection
	// lost with the gRPC server hosting the OltInterAdapterService service
	GetHealthStatus(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[common.Connection, health.HealthStatus], error)
	ProxyOmciRequest(ctx context.Context, in *inter_adapter.OmciMessage, opts ...grpc.CallOption) (*emptypb.Empty, error)
	ProxyOmciRequests(ctx context.Context, in *inter_adapter.OmciMessages, opts ...grpc.CallOption) (*emptypb.Empty, error)
	GetTechProfileInstance(ctx context.Context, in *inter_adapter.TechProfileInstanceRequestMessage, opts ...grpc.CallOption) (*inter_adapter.TechProfileDownloadMessage, error)
}

OltInterAdapterServiceClient is the client API for OltInterAdapterService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type OltInterAdapterServiceServer

type OltInterAdapterServiceServer interface {
	// GetHealthStatus is used by a OltInterAdapterService client to detect a connection
	// lost with the gRPC server hosting the OltInterAdapterService service
	GetHealthStatus(grpc.BidiStreamingServer[common.Connection, health.HealthStatus]) error
	ProxyOmciRequest(context.Context, *inter_adapter.OmciMessage) (*emptypb.Empty, error)
	ProxyOmciRequests(context.Context, *inter_adapter.OmciMessages) (*emptypb.Empty, error)
	GetTechProfileInstance(context.Context, *inter_adapter.TechProfileInstanceRequestMessage) (*inter_adapter.TechProfileDownloadMessage, error)
	// contains filtered or unexported methods
}

OltInterAdapterServiceServer is the server API for OltInterAdapterService service. All implementations must embed UnimplementedOltInterAdapterServiceServer for forward compatibility.

type OltInterAdapterService_GetHealthStatusClient

type OltInterAdapterService_GetHealthStatusClient = grpc.BidiStreamingClient[common.Connection, health.HealthStatus]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type OltInterAdapterService_GetHealthStatusServer

type OltInterAdapterService_GetHealthStatusServer = grpc.BidiStreamingServer[common.Connection, health.HealthStatus]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type UnimplementedOltInterAdapterServiceServer

type UnimplementedOltInterAdapterServiceServer struct{}

UnimplementedOltInterAdapterServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedOltInterAdapterServiceServer) GetHealthStatus

func (UnimplementedOltInterAdapterServiceServer) ProxyOmciRequest

func (UnimplementedOltInterAdapterServiceServer) ProxyOmciRequests

type UnsafeOltInterAdapterServiceServer added in v5.7.1

type UnsafeOltInterAdapterServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeOltInterAdapterServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OltInterAdapterServiceServer will result in compilation errors.

Jump to