Documentation
¶
Index ¶
- Variables
- type AdminState
- type AdminState_Types
- func (AdminState_Types) Descriptor() protoreflect.EnumDescriptor
- func (x AdminState_Types) Enum() *AdminState_Types
- func (AdminState_Types) EnumDescriptor() ([]byte, []int)deprecated
- func (x AdminState_Types) Number() protoreflect.EnumNumber
- func (x AdminState_Types) String() string
- func (AdminState_Types) Type() protoreflect.EnumType
- type ConnectStatus
- type ConnectStatus_Types
- func (ConnectStatus_Types) Descriptor() protoreflect.EnumDescriptor
- func (x ConnectStatus_Types) Enum() *ConnectStatus_Types
- func (ConnectStatus_Types) EnumDescriptor() ([]byte, []int)deprecated
- func (x ConnectStatus_Types) Number() protoreflect.EnumNumber
- func (x ConnectStatus_Types) String() string
- func (ConnectStatus_Types) Type() protoreflect.EnumType
- type Connection
- func (*Connection) Descriptor() ([]byte, []int)deprecated
- func (x *Connection) GetContextInfo() string
- func (x *Connection) GetEndpoint() string
- func (x *Connection) GetKeepAliveInterval() int64
- func (*Connection) ProtoMessage()
- func (x *Connection) ProtoReflect() protoreflect.Message
- func (x *Connection) Reset()
- func (x *Connection) String() string
- type ID
- type IDs
- type Key
- type OperStatus
- type OperStatus_Types
- func (OperStatus_Types) Descriptor() protoreflect.EnumDescriptor
- func (x OperStatus_Types) Enum() *OperStatus_Types
- func (OperStatus_Types) EnumDescriptor() ([]byte, []int)deprecated
- func (x OperStatus_Types) Number() protoreflect.EnumNumber
- func (x OperStatus_Types) String() string
- func (OperStatus_Types) Type() protoreflect.EnumType
- type OperationResp
- func (*OperationResp) Descriptor() ([]byte, []int)deprecated
- func (x *OperationResp) GetAdditionalInfo() string
- func (x *OperationResp) GetCode() OperationResp_OperationReturnCode
- func (*OperationResp) ProtoMessage()
- func (x *OperationResp) ProtoReflect() protoreflect.Message
- func (x *OperationResp) Reset()
- func (x *OperationResp) String() string
- type OperationResp_OperationReturnCode
- func (OperationResp_OperationReturnCode) Descriptor() protoreflect.EnumDescriptor
- func (x OperationResp_OperationReturnCode) Enum() *OperationResp_OperationReturnCode
- func (OperationResp_OperationReturnCode) EnumDescriptor() ([]byte, []int)deprecated
- func (x OperationResp_OperationReturnCode) Number() protoreflect.EnumNumber
- func (x OperationResp_OperationReturnCode) String() string
- func (OperationResp_OperationReturnCode) Type() protoreflect.EnumType
- type PortStatistics
- func (*PortStatistics) Descriptor() ([]byte, []int)deprecated
- func (x *PortStatistics) GetBipErrors() uint64
- func (x *PortStatistics) GetBipUnits() uint64
- func (x *PortStatistics) GetIntfId() uint32
- func (x *PortStatistics) GetRxBcastFrames() uint64
- func (x *PortStatistics) GetRxBcastPackets() uint64deprecated
- func (x *PortStatistics) GetRxBytes() uint64
- func (x *PortStatistics) GetRxCpu() uint64
- func (x *PortStatistics) GetRxCpuOmciPacketsDropped() uint64
- func (x *PortStatistics) GetRxCrcErrors() uint64
- func (x *PortStatistics) GetRxDiscardedFrames() uint64
- func (x *PortStatistics) GetRxErrorFrames() uint64
- func (x *PortStatistics) GetRxErrorPackets() uint64deprecated
- func (x *PortStatistics) GetRxFcsErrorPackets() uint64
- func (x *PortStatistics) GetRxFragmentError() uint64
- func (x *PortStatistics) GetRxFrames() uint64
- func (x *PortStatistics) GetRxFrames_64() uint64
- func (x *PortStatistics) GetRxFrames_65_127() uint64
- func (x *PortStatistics) GetRxFrames_128_255() uint64
- func (x *PortStatistics) GetRxFrames_256_511() uint64
- func (x *PortStatistics) GetRxFrames_512_1023() uint64
- func (x *PortStatistics) GetRxFrames_1024_1518() uint64
- func (x *PortStatistics) GetRxFrames_1519_2047() uint64
- func (x *PortStatistics) GetRxFrames_2048_4095() uint64
- func (x *PortStatistics) GetRxFrames_4096_9216() uint64
- func (x *PortStatistics) GetRxFrames_9217_16383() uint64
- func (x *PortStatistics) GetRxGem() uint64
- func (x *PortStatistics) GetRxGemCorrected() uint64
- func (x *PortStatistics) GetRxGemDropped() uint64
- func (x *PortStatistics) GetRxGemIdle() uint64
- func (x *PortStatistics) GetRxGemIllegal() uint64
- func (x *PortStatistics) GetRxMcastFrames() uint64
- func (x *PortStatistics) GetRxMcastPackets() uint64deprecated
- func (x *PortStatistics) GetRxOmci() uint64
- func (x *PortStatistics) GetRxOmciPacketsCrcError() uint64
- func (x *PortStatistics) GetRxOversizePackets() uint64
- func (x *PortStatistics) GetRxPackets() uint64deprecated
- func (x *PortStatistics) GetRxPacketsDropped() uint64
- func (x *PortStatistics) GetRxRightFrames() uint64
- func (x *PortStatistics) GetRxUcastFrames() uint64
- func (x *PortStatistics) GetRxUcastPackets() uint64deprecated
- func (x *PortStatistics) GetRxUndersizePackets() uint64
- func (x *PortStatistics) GetTimestamp() uint32
- func (x *PortStatistics) GetTxBcastFrames() uint64
- func (x *PortStatistics) GetTxBcastPackets() uint64deprecated
- func (x *PortStatistics) GetTxBytes() uint64
- func (x *PortStatistics) GetTxCpu() uint64
- func (x *PortStatistics) GetTxDroppedIllegalLength() uint64
- func (x *PortStatistics) GetTxDroppedTotal() uint64
- func (x *PortStatistics) GetTxDroppedTpidMiss() uint64
- func (x *PortStatistics) GetTxDroppedVidMiss() uint64
- func (x *PortStatistics) GetTxErrorFrames() uint64
- func (x *PortStatistics) GetTxErrorPackets() uint64deprecated
- func (x *PortStatistics) GetTxFrames() uint64
- func (x *PortStatistics) GetTxFrames_64() uint64
- func (x *PortStatistics) GetTxFrames_65_127() uint64
- func (x *PortStatistics) GetTxFrames_128_255() uint64
- func (x *PortStatistics) GetTxFrames_256_511() uint64
- func (x *PortStatistics) GetTxFrames_512_1023() uint64
- func (x *PortStatistics) GetTxFrames_1024_1518() uint64
- func (x *PortStatistics) GetTxFrames_1519_2047() uint64
- func (x *PortStatistics) GetTxFrames_2048_4095() uint64
- func (x *PortStatistics) GetTxFrames_4096_9216() uint64
- func (x *PortStatistics) GetTxFrames_9217_16383() uint64
- func (x *PortStatistics) GetTxGem() uint64
- func (x *PortStatistics) GetTxMcastFrames() uint64
- func (x *PortStatistics) GetTxMcastPackets() uint64deprecated
- func (x *PortStatistics) GetTxOmci() uint64
- func (x *PortStatistics) GetTxOversizePackets() uint64
- func (x *PortStatistics) GetTxPackets() uint64deprecated
- func (x *PortStatistics) GetTxUcastFrames() uint64
- func (x *PortStatistics) GetTxUcastPackets() uint64deprecated
- func (x *PortStatistics) GetTxUndersizePackets() uint64
- func (*PortStatistics) ProtoMessage()
- func (x *PortStatistics) ProtoReflect() protoreflect.Message
- func (x *PortStatistics) Reset()
- func (x *PortStatistics) String() string
- type TestModeKeys
- func (TestModeKeys) Descriptor() protoreflect.EnumDescriptor
- func (x TestModeKeys) Enum() *TestModeKeys
- func (TestModeKeys) EnumDescriptor() ([]byte, []int)deprecated
- func (x TestModeKeys) Number() protoreflect.EnumNumber
- func (x TestModeKeys) String() string
- func (TestModeKeys) Type() protoreflect.EnumType
Constants ¶
This section is empty.
Variables ¶
var ( TestModeKeys_name = map[int32]string{ 0: "api_test", } TestModeKeys_value = map[string]int32{ "api_test": 0, } )
Enum value maps for TestModeKeys.
var ( AdminState_Types_name = map[int32]string{ 0: "UNKNOWN", 1: "PREPROVISIONED", 2: "ENABLED", 3: "DISABLED", 4: "DOWNLOADING_IMAGE", } AdminState_Types_value = map[string]int32{ "UNKNOWN": 0, "PREPROVISIONED": 1, "ENABLED": 2, "DISABLED": 3, "DOWNLOADING_IMAGE": 4, } )
Enum value maps for AdminState_Types.
var ( OperStatus_Types_name = map[int32]string{ 0: "UNKNOWN", 1: "DISCOVERED", 2: "ACTIVATING", 3: "TESTING", 4: "ACTIVE", 5: "FAILED", 6: "RECONCILING", 7: "RECONCILING_FAILED", 8: "REBOOTED", } OperStatus_Types_value = map[string]int32{ "UNKNOWN": 0, "DISCOVERED": 1, "ACTIVATING": 2, "TESTING": 3, "ACTIVE": 4, "FAILED": 5, "RECONCILING": 6, "RECONCILING_FAILED": 7, "REBOOTED": 8, } )
Enum value maps for OperStatus_Types.
var ( ConnectStatus_Types_name = map[int32]string{ 0: "UNKNOWN", 1: "UNREACHABLE", 2: "REACHABLE", } ConnectStatus_Types_value = map[string]int32{ "UNKNOWN": 0, "UNREACHABLE": 1, "REACHABLE": 2, } )
Enum value maps for ConnectStatus_Types.
var ( OperationResp_OperationReturnCode_name = map[int32]string{ 0: "OPERATION_SUCCESS", 1: "OPERATION_FAILURE", 2: "OPERATION_UNSUPPORTED", 3: "OPERATION_IN_PROGRESS", } OperationResp_OperationReturnCode_value = map[string]int32{ "OPERATION_SUCCESS": 0, "OPERATION_FAILURE": 1, "OPERATION_UNSUPPORTED": 2, "OPERATION_IN_PROGRESS": 3, } )
Enum value maps for OperationResp_OperationReturnCode.
var File_voltha_protos_common_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AdminState ¶
type AdminState struct {
// contains filtered or unexported fields
}
func (*AdminState) Descriptor
deprecated
func (*AdminState) Descriptor() ([]byte, []int)
Deprecated: Use AdminState.ProtoReflect.Descriptor instead.
func (*AdminState) ProtoMessage ¶
func (*AdminState) ProtoMessage()
func (*AdminState) ProtoReflect ¶ added in v5.7.1
func (x *AdminState) ProtoReflect() protoreflect.Message
func (*AdminState) Reset ¶
func (x *AdminState) Reset()
func (*AdminState) String ¶
func (x *AdminState) String() string
type AdminState_Types ¶
type AdminState_Types int32
Administrative State
const ( // The administrative state of the device is unknown AdminState_UNKNOWN AdminState_Types = 0 // The device is pre-provisioned into Voltha, but not contacted by it AdminState_PREPROVISIONED AdminState_Types = 1 // The device is enabled for activation and operation AdminState_ENABLED AdminState_Types = 2 // The device is disabled and shall not perform its intended forwarding // functions other than being available for re-activation. AdminState_DISABLED AdminState_Types = 3 // The device is in the state of image download AdminState_DOWNLOADING_IMAGE AdminState_Types = 4 )
func (AdminState_Types) Descriptor ¶ added in v5.7.1
func (AdminState_Types) Descriptor() protoreflect.EnumDescriptor
func (AdminState_Types) Enum ¶ added in v5.7.1
func (x AdminState_Types) Enum() *AdminState_Types
func (AdminState_Types) EnumDescriptor
deprecated
func (AdminState_Types) EnumDescriptor() ([]byte, []int)
Deprecated: Use AdminState_Types.Descriptor instead.
func (AdminState_Types) Number ¶ added in v5.7.1
func (x AdminState_Types) Number() protoreflect.EnumNumber
func (AdminState_Types) String ¶
func (x AdminState_Types) String() string
func (AdminState_Types) Type ¶ added in v5.7.1
func (AdminState_Types) Type() protoreflect.EnumType
type ConnectStatus ¶
type ConnectStatus struct {
// contains filtered or unexported fields
}
func (*ConnectStatus) Descriptor
deprecated
func (*ConnectStatus) Descriptor() ([]byte, []int)
Deprecated: Use ConnectStatus.ProtoReflect.Descriptor instead.
func (*ConnectStatus) ProtoMessage ¶
func (*ConnectStatus) ProtoMessage()
func (*ConnectStatus) ProtoReflect ¶ added in v5.7.1
func (x *ConnectStatus) ProtoReflect() protoreflect.Message
func (*ConnectStatus) Reset ¶
func (x *ConnectStatus) Reset()
func (*ConnectStatus) String ¶
func (x *ConnectStatus) String() string
type ConnectStatus_Types ¶
type ConnectStatus_Types int32
Connectivity Status
const ( // The device connectivity status is unknown ConnectStatus_UNKNOWN ConnectStatus_Types = 0 // The device cannot be reached by Voltha ConnectStatus_UNREACHABLE ConnectStatus_Types = 1 // There is live communication between device and Voltha ConnectStatus_REACHABLE ConnectStatus_Types = 2 )
func (ConnectStatus_Types) Descriptor ¶ added in v5.7.1
func (ConnectStatus_Types) Descriptor() protoreflect.EnumDescriptor
func (ConnectStatus_Types) Enum ¶ added in v5.7.1
func (x ConnectStatus_Types) Enum() *ConnectStatus_Types
func (ConnectStatus_Types) EnumDescriptor
deprecated
func (ConnectStatus_Types) EnumDescriptor() ([]byte, []int)
Deprecated: Use ConnectStatus_Types.Descriptor instead.
func (ConnectStatus_Types) Number ¶ added in v5.7.1
func (x ConnectStatus_Types) Number() protoreflect.EnumNumber
func (ConnectStatus_Types) String ¶
func (x ConnectStatus_Types) String() string
func (ConnectStatus_Types) Type ¶ added in v5.7.1
func (ConnectStatus_Types) Type() protoreflect.EnumType
type Connection ¶
type Connection struct {
// endpoint is the endpoint sending the request
Endpoint string `protobuf:"bytes,1,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
// contextInfo represents additional contextual information
ContextInfo string `protobuf:"bytes,2,opt,name=contextInfo,proto3" json:"contextInfo,omitempty"`
// keep_alive_interval is used to indicate to the remote endpoint how often it
// will get a keep alive notification
KeepAliveInterval int64 `protobuf:"varint,3,opt,name=keep_alive_interval,json=keepAliveInterval,proto3" json:"keep_alive_interval,omitempty"`
// contains filtered or unexported fields
}
func (*Connection) Descriptor
deprecated
func (*Connection) Descriptor() ([]byte, []int)
Deprecated: Use Connection.ProtoReflect.Descriptor instead.
func (*Connection) GetContextInfo ¶
func (x *Connection) GetContextInfo() string
func (*Connection) GetEndpoint ¶
func (x *Connection) GetEndpoint() string
func (*Connection) GetKeepAliveInterval ¶
func (x *Connection) GetKeepAliveInterval() int64
func (*Connection) ProtoMessage ¶
func (*Connection) ProtoMessage()
func (*Connection) ProtoReflect ¶ added in v5.7.1
func (x *Connection) ProtoReflect() protoreflect.Message
func (*Connection) Reset ¶
func (x *Connection) Reset()
func (*Connection) String ¶
func (x *Connection) String() string
type ID ¶
type ID struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
Convey a resource identifier
func (*ID) Descriptor
deprecated
func (*ID) ProtoMessage ¶
func (*ID) ProtoMessage()
func (*ID) ProtoReflect ¶ added in v5.7.1
func (x *ID) ProtoReflect() protoreflect.Message
type IDs ¶
type IDs struct {
Items []*ID `protobuf:"bytes,1,rep,name=items,proto3" json:"items,omitempty"`
// contains filtered or unexported fields
}
Represents a list of IDs
func (*IDs) Descriptor
deprecated
func (*IDs) ProtoMessage ¶
func (*IDs) ProtoMessage()
func (*IDs) ProtoReflect ¶ added in v5.7.1
func (x *IDs) ProtoReflect() protoreflect.Message
type Key ¶
type Key struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
Full path for KV store
func (*Key) Descriptor
deprecated
func (*Key) ProtoMessage ¶
func (*Key) ProtoMessage()
func (*Key) ProtoReflect ¶ added in v5.7.1
func (x *Key) ProtoReflect() protoreflect.Message
type OperStatus ¶
type OperStatus struct {
// contains filtered or unexported fields
}
func (*OperStatus) Descriptor
deprecated
func (*OperStatus) Descriptor() ([]byte, []int)
Deprecated: Use OperStatus.ProtoReflect.Descriptor instead.
func (*OperStatus) ProtoMessage ¶
func (*OperStatus) ProtoMessage()
func (*OperStatus) ProtoReflect ¶ added in v5.7.1
func (x *OperStatus) ProtoReflect() protoreflect.Message
func (*OperStatus) Reset ¶
func (x *OperStatus) Reset()
func (*OperStatus) String ¶
func (x *OperStatus) String() string
type OperStatus_Types ¶
type OperStatus_Types int32
Operational Status
const ( // The status of the device is unknown at this point OperStatus_UNKNOWN OperStatus_Types = 0 // The device has been discovered, but not yet activated OperStatus_DISCOVERED OperStatus_Types = 1 // The device is being activated (booted, rebooted, upgraded, etc.) OperStatus_ACTIVATING OperStatus_Types = 2 // Service impacting tests are being conducted OperStatus_TESTING OperStatus_Types = 3 // The device is up and active OperStatus_ACTIVE OperStatus_Types = 4 // The device has failed and cannot fulfill its intended role OperStatus_FAILED OperStatus_Types = 5 // The device is reconciling OperStatus_RECONCILING OperStatus_Types = 6 // The device is in reconciling failed OperStatus_RECONCILING_FAILED OperStatus_Types = 7 // The device has rebooted OperStatus_REBOOTED OperStatus_Types = 8 )
func (OperStatus_Types) Descriptor ¶ added in v5.7.1
func (OperStatus_Types) Descriptor() protoreflect.EnumDescriptor
func (OperStatus_Types) Enum ¶ added in v5.7.1
func (x OperStatus_Types) Enum() *OperStatus_Types
func (OperStatus_Types) EnumDescriptor
deprecated
func (OperStatus_Types) EnumDescriptor() ([]byte, []int)
Deprecated: Use OperStatus_Types.Descriptor instead.
func (OperStatus_Types) Number ¶ added in v5.7.1
func (x OperStatus_Types) Number() protoreflect.EnumNumber
func (OperStatus_Types) String ¶
func (x OperStatus_Types) String() string
func (OperStatus_Types) Type ¶ added in v5.7.1
func (OperStatus_Types) Type() protoreflect.EnumType
type OperationResp ¶
type OperationResp struct {
// Return code
Code OperationResp_OperationReturnCode `protobuf:"varint,1,opt,name=code,proto3,enum=common.OperationResp_OperationReturnCode" json:"code,omitempty"`
// Additional Info
AdditionalInfo string `protobuf:"bytes,2,opt,name=additional_info,json=additionalInfo,proto3" json:"additional_info,omitempty"`
// contains filtered or unexported fields
}
func (*OperationResp) Descriptor
deprecated
func (*OperationResp) Descriptor() ([]byte, []int)
Deprecated: Use OperationResp.ProtoReflect.Descriptor instead.
func (*OperationResp) GetAdditionalInfo ¶
func (x *OperationResp) GetAdditionalInfo() string
func (*OperationResp) GetCode ¶
func (x *OperationResp) GetCode() OperationResp_OperationReturnCode
func (*OperationResp) ProtoMessage ¶
func (*OperationResp) ProtoMessage()
func (*OperationResp) ProtoReflect ¶ added in v5.7.1
func (x *OperationResp) ProtoReflect() protoreflect.Message
func (*OperationResp) Reset ¶
func (x *OperationResp) Reset()
func (*OperationResp) String ¶
func (x *OperationResp) String() string
type OperationResp_OperationReturnCode ¶
type OperationResp_OperationReturnCode int32
const ( OperationResp_OPERATION_SUCCESS OperationResp_OperationReturnCode = 0 OperationResp_OPERATION_FAILURE OperationResp_OperationReturnCode = 1 OperationResp_OPERATION_UNSUPPORTED OperationResp_OperationReturnCode = 2 OperationResp_OPERATION_IN_PROGRESS OperationResp_OperationReturnCode = 3 )
func (OperationResp_OperationReturnCode) Descriptor ¶ added in v5.7.1
func (OperationResp_OperationReturnCode) Descriptor() protoreflect.EnumDescriptor
func (OperationResp_OperationReturnCode) Enum ¶ added in v5.7.1
func (x OperationResp_OperationReturnCode) Enum() *OperationResp_OperationReturnCode
func (OperationResp_OperationReturnCode) EnumDescriptor
deprecated
func (OperationResp_OperationReturnCode) EnumDescriptor() ([]byte, []int)
Deprecated: Use OperationResp_OperationReturnCode.Descriptor instead.
func (OperationResp_OperationReturnCode) Number ¶ added in v5.7.1
func (x OperationResp_OperationReturnCode) Number() protoreflect.EnumNumber
func (OperationResp_OperationReturnCode) String ¶
func (x OperationResp_OperationReturnCode) String() string
func (OperationResp_OperationReturnCode) Type ¶ added in v5.7.1
func (OperationResp_OperationReturnCode) Type() protoreflect.EnumType
type PortStatistics ¶ added in v5.6.5
type PortStatistics struct {
IntfId uint32 `protobuf:"fixed32,1,opt,name=intf_id,json=intfId,proto3" json:"intf_id,omitempty"`
RxBytes uint64 `protobuf:"fixed64,2,opt,name=rx_bytes,json=rxBytes,proto3" json:"rx_bytes,omitempty"`
// Deprecated: OLT being a Layer 2 device, use rx_frames (field 17) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
RxPackets uint64 `protobuf:"fixed64,3,opt,name=rx_packets,json=rxPackets,proto3" json:"rx_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use rx_ucast_frames (field 63) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
RxUcastPackets uint64 `protobuf:"fixed64,4,opt,name=rx_ucast_packets,json=rxUcastPackets,proto3" json:"rx_ucast_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use rx_mcast_frames (field 64) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
RxMcastPackets uint64 `protobuf:"fixed64,5,opt,name=rx_mcast_packets,json=rxMcastPackets,proto3" json:"rx_mcast_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use rx_bcast_frames (field 65) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
RxBcastPackets uint64 `protobuf:"fixed64,6,opt,name=rx_bcast_packets,json=rxBcastPackets,proto3" json:"rx_bcast_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use rx_error_frames (field 66) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
RxErrorPackets uint64 `protobuf:"fixed64,7,opt,name=rx_error_packets,json=rxErrorPackets,proto3" json:"rx_error_packets,omitempty"`
RxFrames uint64 `protobuf:"fixed64,17,opt,name=rx_frames,json=rxFrames,proto3" json:"rx_frames,omitempty"`
RxFrames_64 uint64 `protobuf:"fixed64,18,opt,name=rx_frames_64,json=rxFrames64,proto3" json:"rx_frames_64,omitempty"`
RxFrames_65_127 uint64 `protobuf:"fixed64,19,opt,name=rx_frames_65_127,json=rxFrames65127,proto3" json:"rx_frames_65_127,omitempty"`
RxFrames_128_255 uint64 `protobuf:"fixed64,20,opt,name=rx_frames_128_255,json=rxFrames128255,proto3" json:"rx_frames_128_255,omitempty"`
RxFrames_256_511 uint64 `protobuf:"fixed64,21,opt,name=rx_frames_256_511,json=rxFrames256511,proto3" json:"rx_frames_256_511,omitempty"`
RxFrames_512_1023 uint64 `protobuf:"fixed64,22,opt,name=rx_frames_512_1023,json=rxFrames5121023,proto3" json:"rx_frames_512_1023,omitempty"`
RxFrames_1024_1518 uint64 `protobuf:"fixed64,23,opt,name=rx_frames_1024_1518,json=rxFrames10241518,proto3" json:"rx_frames_1024_1518,omitempty"`
RxFrames_1519_2047 uint64 `protobuf:"fixed64,24,opt,name=rx_frames_1519_2047,json=rxFrames15192047,proto3" json:"rx_frames_1519_2047,omitempty"`
RxFrames_2048_4095 uint64 `protobuf:"fixed64,25,opt,name=rx_frames_2048_4095,json=rxFrames20484095,proto3" json:"rx_frames_2048_4095,omitempty"`
RxFrames_4096_9216 uint64 `protobuf:"fixed64,26,opt,name=rx_frames_4096_9216,json=rxFrames40969216,proto3" json:"rx_frames_4096_9216,omitempty"`
RxFrames_9217_16383 uint64 `protobuf:"fixed64,27,opt,name=rx_frames_9217_16383,json=rxFrames921716383,proto3" json:"rx_frames_9217_16383,omitempty"`
RxCrcErrors uint64 `protobuf:"fixed64,14,opt,name=rx_crc_errors,json=rxCrcErrors,proto3" json:"rx_crc_errors,omitempty"`
RxUndersizePackets uint64 `protobuf:"fixed64,39,opt,name=rxUndersizePackets,proto3" json:"rxUndersizePackets,omitempty"`
RxOversizePackets uint64 `protobuf:"fixed64,40,opt,name=rxOversizePackets,proto3" json:"rxOversizePackets,omitempty"`
RxGem uint64 `protobuf:"fixed64,43,opt,name=rxGem,proto3" json:"rxGem,omitempty"`
RxGemDropped uint64 `protobuf:"fixed64,44,opt,name=rxGemDropped,proto3" json:"rxGemDropped,omitempty"`
RxGemIdle uint64 `protobuf:"fixed64,45,opt,name=rxGemIdle,proto3" json:"rxGemIdle,omitempty"`
RxGemCorrected uint64 `protobuf:"fixed64,46,opt,name=rxGemCorrected,proto3" json:"rxGemCorrected,omitempty"`
RxGemIllegal uint64 `protobuf:"fixed64,47,opt,name=rxGemIllegal,proto3" json:"rxGemIllegal,omitempty"`
RxFragmentError uint64 `protobuf:"fixed64,48,opt,name=rxFragmentError,proto3" json:"rxFragmentError,omitempty"`
RxPacketsDropped uint64 `protobuf:"fixed64,49,opt,name=rxPacketsDropped,proto3" json:"rxPacketsDropped,omitempty"`
RxCpuOmciPacketsDropped uint64 `protobuf:"fixed64,50,opt,name=rxCpuOmciPacketsDropped,proto3" json:"rxCpuOmciPacketsDropped,omitempty"`
RxCpu uint64 `protobuf:"fixed64,51,opt,name=rxCpu,proto3" json:"rxCpu,omitempty"`
RxOmci uint64 `protobuf:"fixed64,52,opt,name=rxOmci,proto3" json:"rxOmci,omitempty"`
RxOmciPacketsCrcError uint64 `protobuf:"fixed64,53,opt,name=rxOmciPacketsCrcError,proto3" json:"rxOmciPacketsCrcError,omitempty"`
RxFcsErrorPackets uint64 `protobuf:"fixed64,62,opt,name=rxFcsErrorPackets,proto3" json:"rxFcsErrorPackets,omitempty"`
TxBytes uint64 `protobuf:"fixed64,8,opt,name=tx_bytes,json=txBytes,proto3" json:"tx_bytes,omitempty"`
// Deprecated: OLT being a Layer 2 device, use tx_frames (field 28) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
TxPackets uint64 `protobuf:"fixed64,9,opt,name=tx_packets,json=txPackets,proto3" json:"tx_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use tx_ucast_frames (field 68) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
TxUcastPackets uint64 `protobuf:"fixed64,10,opt,name=tx_ucast_packets,json=txUcastPackets,proto3" json:"tx_ucast_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use tx_mcast_frames (field 69) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
TxMcastPackets uint64 `protobuf:"fixed64,11,opt,name=tx_mcast_packets,json=txMcastPackets,proto3" json:"tx_mcast_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use tx_bcast_frames (field 70) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
TxBcastPackets uint64 `protobuf:"fixed64,12,opt,name=tx_bcast_packets,json=txBcastPackets,proto3" json:"tx_bcast_packets,omitempty"`
// Deprecated: OLT being a Layer 2 device, use tx_error_frames (field 71) instead
//
// Deprecated: Marked as deprecated in voltha_protos/common.proto.
TxErrorPackets uint64 `protobuf:"fixed64,13,opt,name=tx_error_packets,json=txErrorPackets,proto3" json:"tx_error_packets,omitempty"`
TxFrames uint64 `protobuf:"fixed64,28,opt,name=tx_frames,json=txFrames,proto3" json:"tx_frames,omitempty"`
TxFrames_64 uint64 `protobuf:"fixed64,29,opt,name=tx_frames_64,json=txFrames64,proto3" json:"tx_frames_64,omitempty"`
TxFrames_65_127 uint64 `protobuf:"fixed64,30,opt,name=tx_frames_65_127,json=txFrames65127,proto3" json:"tx_frames_65_127,omitempty"`
TxFrames_128_255 uint64 `protobuf:"fixed64,31,opt,name=tx_frames_128_255,json=txFrames128255,proto3" json:"tx_frames_128_255,omitempty"`
TxFrames_256_511 uint64 `protobuf:"fixed64,32,opt,name=tx_frames_256_511,json=txFrames256511,proto3" json:"tx_frames_256_511,omitempty"`
TxFrames_512_1023 uint64 `protobuf:"fixed64,33,opt,name=tx_frames_512_1023,json=txFrames5121023,proto3" json:"tx_frames_512_1023,omitempty"`
TxFrames_1024_1518 uint64 `protobuf:"fixed64,34,opt,name=tx_frames_1024_1518,json=txFrames10241518,proto3" json:"tx_frames_1024_1518,omitempty"`
TxFrames_1519_2047 uint64 `protobuf:"fixed64,35,opt,name=tx_frames_1519_2047,json=txFrames15192047,proto3" json:"tx_frames_1519_2047,omitempty"`
TxFrames_2048_4095 uint64 `protobuf:"fixed64,36,opt,name=tx_frames_2048_4095,json=txFrames20484095,proto3" json:"tx_frames_2048_4095,omitempty"`
TxFrames_4096_9216 uint64 `protobuf:"fixed64,37,opt,name=tx_frames_4096_9216,json=txFrames40969216,proto3" json:"tx_frames_4096_9216,omitempty"`
TxFrames_9217_16383 uint64 `protobuf:"fixed64,38,opt,name=tx_frames_9217_16383,json=txFrames921716383,proto3" json:"tx_frames_9217_16383,omitempty"`
TxUndersizePackets uint64 `protobuf:"fixed64,41,opt,name=txUndersizePackets,proto3" json:"txUndersizePackets,omitempty"`
TxOversizePackets uint64 `protobuf:"fixed64,42,opt,name=txOversizePackets,proto3" json:"txOversizePackets,omitempty"`
TxGem uint64 `protobuf:"fixed64,54,opt,name=txGem,proto3" json:"txGem,omitempty"`
TxCpu uint64 `protobuf:"fixed64,55,opt,name=txCpu,proto3" json:"txCpu,omitempty"`
TxOmci uint64 `protobuf:"fixed64,56,opt,name=txOmci,proto3" json:"txOmci,omitempty"`
TxDroppedIllegalLength uint64 `protobuf:"fixed64,57,opt,name=txDroppedIllegalLength,proto3" json:"txDroppedIllegalLength,omitempty"`
TxDroppedTpidMiss uint64 `protobuf:"fixed64,58,opt,name=txDroppedTpidMiss,proto3" json:"txDroppedTpidMiss,omitempty"`
TxDroppedVidMiss uint64 `protobuf:"fixed64,59,opt,name=txDroppedVidMiss,proto3" json:"txDroppedVidMiss,omitempty"`
TxDroppedTotal uint64 `protobuf:"fixed64,60,opt,name=txDroppedTotal,proto3" json:"txDroppedTotal,omitempty"`
BipErrors uint64 `protobuf:"fixed64,15,opt,name=bip_errors,json=bipErrors,proto3" json:"bip_errors,omitempty"`
BipUnits uint64 `protobuf:"fixed64,61,opt,name=bip_units,json=bipUnits,proto3" json:"bip_units,omitempty"`
Timestamp uint32 `protobuf:"fixed32,16,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
RxUcastFrames uint64 `protobuf:"fixed64,63,opt,name=rx_ucast_frames,json=rxUcastFrames,proto3" json:"rx_ucast_frames,omitempty"`
RxMcastFrames uint64 `protobuf:"fixed64,64,opt,name=rx_mcast_frames,json=rxMcastFrames,proto3" json:"rx_mcast_frames,omitempty"`
RxBcastFrames uint64 `protobuf:"fixed64,65,opt,name=rx_bcast_frames,json=rxBcastFrames,proto3" json:"rx_bcast_frames,omitempty"`
RxErrorFrames uint64 `protobuf:"fixed64,66,opt,name=rx_error_frames,json=rxErrorFrames,proto3" json:"rx_error_frames,omitempty"`
RxRightFrames uint64 `protobuf:"fixed64,67,opt,name=rx_right_frames,json=rxRightFrames,proto3" json:"rx_right_frames,omitempty"`
TxUcastFrames uint64 `protobuf:"fixed64,68,opt,name=tx_ucast_frames,json=txUcastFrames,proto3" json:"tx_ucast_frames,omitempty"`
TxMcastFrames uint64 `protobuf:"fixed64,69,opt,name=tx_mcast_frames,json=txMcastFrames,proto3" json:"tx_mcast_frames,omitempty"`
TxBcastFrames uint64 `protobuf:"fixed64,70,opt,name=tx_bcast_frames,json=txBcastFrames,proto3" json:"tx_bcast_frames,omitempty"`
TxErrorFrames uint64 `protobuf:"fixed64,71,opt,name=tx_error_frames,json=txErrorFrames,proto3" json:"tx_error_frames,omitempty"`
RxDiscardedFrames uint64 `protobuf:"fixed64,72,opt,name=rx_discarded_frames,json=rxDiscardedFrames,proto3" json:"rx_discarded_frames,omitempty"`
// contains filtered or unexported fields
}
func (*PortStatistics) Descriptor
deprecated
added in
v5.6.5
func (*PortStatistics) Descriptor() ([]byte, []int)
Deprecated: Use PortStatistics.ProtoReflect.Descriptor instead.
func (*PortStatistics) GetBipErrors ¶ added in v5.6.5
func (x *PortStatistics) GetBipErrors() uint64
func (*PortStatistics) GetBipUnits ¶ added in v5.6.5
func (x *PortStatistics) GetBipUnits() uint64
func (*PortStatistics) GetIntfId ¶ added in v5.6.5
func (x *PortStatistics) GetIntfId() uint32
func (*PortStatistics) GetRxBcastFrames ¶ added in v5.6.8
func (x *PortStatistics) GetRxBcastFrames() uint64
func (*PortStatistics) GetRxBcastPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetRxBcastPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetRxBytes ¶ added in v5.6.5
func (x *PortStatistics) GetRxBytes() uint64
func (*PortStatistics) GetRxCpu ¶ added in v5.6.5
func (x *PortStatistics) GetRxCpu() uint64
func (*PortStatistics) GetRxCpuOmciPacketsDropped ¶ added in v5.6.5
func (x *PortStatistics) GetRxCpuOmciPacketsDropped() uint64
func (*PortStatistics) GetRxCrcErrors ¶ added in v5.6.5
func (x *PortStatistics) GetRxCrcErrors() uint64
func (*PortStatistics) GetRxDiscardedFrames ¶ added in v5.6.8
func (x *PortStatistics) GetRxDiscardedFrames() uint64
func (*PortStatistics) GetRxErrorFrames ¶ added in v5.6.8
func (x *PortStatistics) GetRxErrorFrames() uint64
func (*PortStatistics) GetRxErrorPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetRxErrorPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetRxFcsErrorPackets ¶ added in v5.6.5
func (x *PortStatistics) GetRxFcsErrorPackets() uint64
func (*PortStatistics) GetRxFragmentError ¶ added in v5.6.5
func (x *PortStatistics) GetRxFragmentError() uint64
func (*PortStatistics) GetRxFrames ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames() uint64
func (*PortStatistics) GetRxFrames_64 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_64() uint64
func (*PortStatistics) GetRxFrames_65_127 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_65_127() uint64
func (*PortStatistics) GetRxFrames_128_255 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_128_255() uint64
func (*PortStatistics) GetRxFrames_256_511 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_256_511() uint64
func (*PortStatistics) GetRxFrames_512_1023 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_512_1023() uint64
func (*PortStatistics) GetRxFrames_1024_1518 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_1024_1518() uint64
func (*PortStatistics) GetRxFrames_1519_2047 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_1519_2047() uint64
func (*PortStatistics) GetRxFrames_2048_4095 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_2048_4095() uint64
func (*PortStatistics) GetRxFrames_4096_9216 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_4096_9216() uint64
func (*PortStatistics) GetRxFrames_9217_16383 ¶ added in v5.6.5
func (x *PortStatistics) GetRxFrames_9217_16383() uint64
func (*PortStatistics) GetRxGem ¶ added in v5.6.5
func (x *PortStatistics) GetRxGem() uint64
func (*PortStatistics) GetRxGemCorrected ¶ added in v5.6.5
func (x *PortStatistics) GetRxGemCorrected() uint64
func (*PortStatistics) GetRxGemDropped ¶ added in v5.6.5
func (x *PortStatistics) GetRxGemDropped() uint64
func (*PortStatistics) GetRxGemIdle ¶ added in v5.6.5
func (x *PortStatistics) GetRxGemIdle() uint64
func (*PortStatistics) GetRxGemIllegal ¶ added in v5.6.5
func (x *PortStatistics) GetRxGemIllegal() uint64
func (*PortStatistics) GetRxMcastFrames ¶ added in v5.6.8
func (x *PortStatistics) GetRxMcastFrames() uint64
func (*PortStatistics) GetRxMcastPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetRxMcastPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetRxOmci ¶ added in v5.6.5
func (x *PortStatistics) GetRxOmci() uint64
func (*PortStatistics) GetRxOmciPacketsCrcError ¶ added in v5.6.5
func (x *PortStatistics) GetRxOmciPacketsCrcError() uint64
func (*PortStatistics) GetRxOversizePackets ¶ added in v5.6.5
func (x *PortStatistics) GetRxOversizePackets() uint64
func (*PortStatistics) GetRxPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetRxPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetRxPacketsDropped ¶ added in v5.6.5
func (x *PortStatistics) GetRxPacketsDropped() uint64
func (*PortStatistics) GetRxRightFrames ¶ added in v5.6.8
func (x *PortStatistics) GetRxRightFrames() uint64
func (*PortStatistics) GetRxUcastFrames ¶ added in v5.6.8
func (x *PortStatistics) GetRxUcastFrames() uint64
func (*PortStatistics) GetRxUcastPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetRxUcastPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetRxUndersizePackets ¶ added in v5.6.5
func (x *PortStatistics) GetRxUndersizePackets() uint64
func (*PortStatistics) GetTimestamp ¶ added in v5.6.5
func (x *PortStatistics) GetTimestamp() uint32
func (*PortStatistics) GetTxBcastFrames ¶ added in v5.6.8
func (x *PortStatistics) GetTxBcastFrames() uint64
func (*PortStatistics) GetTxBcastPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetTxBcastPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetTxBytes ¶ added in v5.6.5
func (x *PortStatistics) GetTxBytes() uint64
func (*PortStatistics) GetTxCpu ¶ added in v5.6.5
func (x *PortStatistics) GetTxCpu() uint64
func (*PortStatistics) GetTxDroppedIllegalLength ¶ added in v5.6.5
func (x *PortStatistics) GetTxDroppedIllegalLength() uint64
func (*PortStatistics) GetTxDroppedTotal ¶ added in v5.6.5
func (x *PortStatistics) GetTxDroppedTotal() uint64
func (*PortStatistics) GetTxDroppedTpidMiss ¶ added in v5.6.5
func (x *PortStatistics) GetTxDroppedTpidMiss() uint64
func (*PortStatistics) GetTxDroppedVidMiss ¶ added in v5.6.5
func (x *PortStatistics) GetTxDroppedVidMiss() uint64
func (*PortStatistics) GetTxErrorFrames ¶ added in v5.6.8
func (x *PortStatistics) GetTxErrorFrames() uint64
func (*PortStatistics) GetTxErrorPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetTxErrorPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetTxFrames ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames() uint64
func (*PortStatistics) GetTxFrames_64 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_64() uint64
func (*PortStatistics) GetTxFrames_65_127 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_65_127() uint64
func (*PortStatistics) GetTxFrames_128_255 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_128_255() uint64
func (*PortStatistics) GetTxFrames_256_511 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_256_511() uint64
func (*PortStatistics) GetTxFrames_512_1023 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_512_1023() uint64
func (*PortStatistics) GetTxFrames_1024_1518 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_1024_1518() uint64
func (*PortStatistics) GetTxFrames_1519_2047 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_1519_2047() uint64
func (*PortStatistics) GetTxFrames_2048_4095 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_2048_4095() uint64
func (*PortStatistics) GetTxFrames_4096_9216 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_4096_9216() uint64
func (*PortStatistics) GetTxFrames_9217_16383 ¶ added in v5.6.5
func (x *PortStatistics) GetTxFrames_9217_16383() uint64
func (*PortStatistics) GetTxGem ¶ added in v5.6.5
func (x *PortStatistics) GetTxGem() uint64
func (*PortStatistics) GetTxMcastFrames ¶ added in v5.6.8
func (x *PortStatistics) GetTxMcastFrames() uint64
func (*PortStatistics) GetTxMcastPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetTxMcastPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetTxOmci ¶ added in v5.6.5
func (x *PortStatistics) GetTxOmci() uint64
func (*PortStatistics) GetTxOversizePackets ¶ added in v5.6.5
func (x *PortStatistics) GetTxOversizePackets() uint64
func (*PortStatistics) GetTxPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetTxPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetTxUcastFrames ¶ added in v5.6.8
func (x *PortStatistics) GetTxUcastFrames() uint64
func (*PortStatistics) GetTxUcastPackets
deprecated
added in
v5.6.5
func (x *PortStatistics) GetTxUcastPackets() uint64
Deprecated: Marked as deprecated in voltha_protos/common.proto.
func (*PortStatistics) GetTxUndersizePackets ¶ added in v5.6.5
func (x *PortStatistics) GetTxUndersizePackets() uint64
func (*PortStatistics) ProtoMessage ¶ added in v5.6.5
func (*PortStatistics) ProtoMessage()
func (*PortStatistics) ProtoReflect ¶ added in v5.7.1
func (x *PortStatistics) ProtoReflect() protoreflect.Message
func (*PortStatistics) Reset ¶ added in v5.6.5
func (x *PortStatistics) Reset()
func (*PortStatistics) String ¶ added in v5.6.5
func (x *PortStatistics) String() string
type TestModeKeys ¶
type TestModeKeys int32
const (
TestModeKeys_api_test TestModeKeys = 0
)
func (TestModeKeys) Descriptor ¶ added in v5.7.1
func (TestModeKeys) Descriptor() protoreflect.EnumDescriptor
func (TestModeKeys) Enum ¶ added in v5.7.1
func (x TestModeKeys) Enum() *TestModeKeys
func (TestModeKeys) EnumDescriptor
deprecated
func (TestModeKeys) EnumDescriptor() ([]byte, []int)
Deprecated: Use TestModeKeys.Descriptor instead.
func (TestModeKeys) Number ¶ added in v5.7.1
func (x TestModeKeys) Number() protoreflect.EnumNumber
func (TestModeKeys) String ¶
func (x TestModeKeys) String() string
func (TestModeKeys) Type ¶ added in v5.7.1
func (TestModeKeys) Type() protoreflect.EnumType