Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterOnuInterAdapterServiceServer(s grpc.ServiceRegistrar, srv OnuInterAdapterServiceServer)
- type OnuInterAdapterServiceClient
- type OnuInterAdapterServiceServer
- type OnuInterAdapterService_GetHealthStatusClient
- type OnuInterAdapterService_GetHealthStatusServer
- type UnimplementedOnuInterAdapterServiceServer
- func (UnimplementedOnuInterAdapterServiceServer) DeleteGemPort(context.Context, *inter_adapter.DeleteGemPortMessage) (*emptypb.Empty, error)
- func (UnimplementedOnuInterAdapterServiceServer) DeleteTCont(context.Context, *inter_adapter.DeleteTcontMessage) (*emptypb.Empty, error)
- func (UnimplementedOnuInterAdapterServiceServer) DownloadTechProfile(context.Context, *inter_adapter.TechProfileDownloadMessage) (*emptypb.Empty, error)
- func (UnimplementedOnuInterAdapterServiceServer) GetHealthStatus(grpc.BidiStreamingServer[common.Connection, health.HealthStatus]) error
- func (UnimplementedOnuInterAdapterServiceServer) OmciIndication(context.Context, *inter_adapter.OmciMessage) (*emptypb.Empty, error)
- func (UnimplementedOnuInterAdapterServiceServer) OnuIndication(context.Context, *inter_adapter.OnuIndicationMessage) (*emptypb.Empty, error)
- type UnsafeOnuInterAdapterServiceServer
Constants ¶
const ( OnuInterAdapterService_GetHealthStatus_FullMethodName = "/onu_inter_adapter_service.OnuInterAdapterService/GetHealthStatus" OnuInterAdapterService_OnuIndication_FullMethodName = "/onu_inter_adapter_service.OnuInterAdapterService/OnuIndication" OnuInterAdapterService_OmciIndication_FullMethodName = "/onu_inter_adapter_service.OnuInterAdapterService/OmciIndication" OnuInterAdapterService_DownloadTechProfile_FullMethodName = "/onu_inter_adapter_service.OnuInterAdapterService/DownloadTechProfile" OnuInterAdapterService_DeleteGemPort_FullMethodName = "/onu_inter_adapter_service.OnuInterAdapterService/DeleteGemPort" OnuInterAdapterService_DeleteTCont_FullMethodName = "/onu_inter_adapter_service.OnuInterAdapterService/DeleteTCont" )
Variables ¶
var File_voltha_protos_onu_inter_adapter_service_proto protoreflect.FileDescriptor
var OnuInterAdapterService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "onu_inter_adapter_service.OnuInterAdapterService", HandlerType: (*OnuInterAdapterServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "OnuIndication", Handler: _OnuInterAdapterService_OnuIndication_Handler, }, { MethodName: "OmciIndication", Handler: _OnuInterAdapterService_OmciIndication_Handler, }, { MethodName: "DownloadTechProfile", Handler: _OnuInterAdapterService_DownloadTechProfile_Handler, }, { MethodName: "DeleteGemPort", Handler: _OnuInterAdapterService_DeleteGemPort_Handler, }, { MethodName: "DeleteTCont", Handler: _OnuInterAdapterService_DeleteTCont_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "GetHealthStatus", Handler: _OnuInterAdapterService_GetHealthStatus_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "voltha_protos/onu_inter_adapter_service.proto", }
OnuInterAdapterService_ServiceDesc is the grpc.ServiceDesc for OnuInterAdapterService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterOnuInterAdapterServiceServer ¶
func RegisterOnuInterAdapterServiceServer(s grpc.ServiceRegistrar, srv OnuInterAdapterServiceServer)
Types ¶
type OnuInterAdapterServiceClient ¶
type OnuInterAdapterServiceClient interface {
// GetHealthStatus is used by a OnuInterAdapterService client to detect a connection
// lost with the gRPC server hosting the OnuInterAdapterService service
GetHealthStatus(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[common.Connection, health.HealthStatus], error)
OnuIndication(ctx context.Context, in *inter_adapter.OnuIndicationMessage, opts ...grpc.CallOption) (*emptypb.Empty, error)
OmciIndication(ctx context.Context, in *inter_adapter.OmciMessage, opts ...grpc.CallOption) (*emptypb.Empty, error)
DownloadTechProfile(ctx context.Context, in *inter_adapter.TechProfileDownloadMessage, opts ...grpc.CallOption) (*emptypb.Empty, error)
DeleteGemPort(ctx context.Context, in *inter_adapter.DeleteGemPortMessage, opts ...grpc.CallOption) (*emptypb.Empty, error)
DeleteTCont(ctx context.Context, in *inter_adapter.DeleteTcontMessage, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
OnuInterAdapterServiceClient is the client API for OnuInterAdapterService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewOnuInterAdapterServiceClient ¶
func NewOnuInterAdapterServiceClient(cc grpc.ClientConnInterface) OnuInterAdapterServiceClient
type OnuInterAdapterServiceServer ¶
type OnuInterAdapterServiceServer interface {
// GetHealthStatus is used by a OnuInterAdapterService client to detect a connection
// lost with the gRPC server hosting the OnuInterAdapterService service
GetHealthStatus(grpc.BidiStreamingServer[common.Connection, health.HealthStatus]) error
OnuIndication(context.Context, *inter_adapter.OnuIndicationMessage) (*emptypb.Empty, error)
OmciIndication(context.Context, *inter_adapter.OmciMessage) (*emptypb.Empty, error)
DownloadTechProfile(context.Context, *inter_adapter.TechProfileDownloadMessage) (*emptypb.Empty, error)
DeleteGemPort(context.Context, *inter_adapter.DeleteGemPortMessage) (*emptypb.Empty, error)
DeleteTCont(context.Context, *inter_adapter.DeleteTcontMessage) (*emptypb.Empty, error)
// contains filtered or unexported methods
}
OnuInterAdapterServiceServer is the server API for OnuInterAdapterService service. All implementations must embed UnimplementedOnuInterAdapterServiceServer for forward compatibility.
type OnuInterAdapterService_GetHealthStatusClient ¶
type OnuInterAdapterService_GetHealthStatusClient = grpc.BidiStreamingClient[common.Connection, health.HealthStatus]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type OnuInterAdapterService_GetHealthStatusServer ¶
type OnuInterAdapterService_GetHealthStatusServer = grpc.BidiStreamingServer[common.Connection, health.HealthStatus]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedOnuInterAdapterServiceServer ¶
type UnimplementedOnuInterAdapterServiceServer struct{}
UnimplementedOnuInterAdapterServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedOnuInterAdapterServiceServer) DeleteGemPort ¶
func (UnimplementedOnuInterAdapterServiceServer) DeleteGemPort(context.Context, *inter_adapter.DeleteGemPortMessage) (*emptypb.Empty, error)
func (UnimplementedOnuInterAdapterServiceServer) DeleteTCont ¶
func (UnimplementedOnuInterAdapterServiceServer) DeleteTCont(context.Context, *inter_adapter.DeleteTcontMessage) (*emptypb.Empty, error)
func (UnimplementedOnuInterAdapterServiceServer) DownloadTechProfile ¶
func (UnimplementedOnuInterAdapterServiceServer) DownloadTechProfile(context.Context, *inter_adapter.TechProfileDownloadMessage) (*emptypb.Empty, error)
func (UnimplementedOnuInterAdapterServiceServer) GetHealthStatus ¶
func (UnimplementedOnuInterAdapterServiceServer) GetHealthStatus(grpc.BidiStreamingServer[common.Connection, health.HealthStatus]) error
func (UnimplementedOnuInterAdapterServiceServer) OmciIndication ¶
func (UnimplementedOnuInterAdapterServiceServer) OmciIndication(context.Context, *inter_adapter.OmciMessage) (*emptypb.Empty, error)
func (UnimplementedOnuInterAdapterServiceServer) OnuIndication ¶
func (UnimplementedOnuInterAdapterServiceServer) OnuIndication(context.Context, *inter_adapter.OnuIndicationMessage) (*emptypb.Empty, error)
type UnsafeOnuInterAdapterServiceServer ¶ added in v5.7.1
type UnsafeOnuInterAdapterServiceServer interface {
// contains filtered or unexported methods
}
UnsafeOnuInterAdapterServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OnuInterAdapterServiceServer will result in compilation errors.